@@ -32,35 +32,21 @@ class LightSensor(Thing):
                      }))
 
         self.ioloop = tornado.ioloop.IOLoop.current()
-
-        logging.info('bind to port ' + str(gpio_number))
-        self.gpio_number = gpio_number
+        logging.info('bind to gpio ' + str(gpio_number))
         GPIO.setmode(GPIO.BCM)
-        GPIO.setup(self.gpio_number, GPIO.IN)
-        self.bright.notify_of_external_update(self.read_gpio())
-        GPIO.add_event_detect(self.gpio_number, GPIO.BOTH, callback=self.update, bouncetime=5)
+        GPIO.setup(gpio_number, GPIO.IN)
+        GPIO.add_event_detect(gpio_number, GPIO.BOTH, callback=self.__update, bouncetime=5)
+        self.__update(gpio_number)
 
-
-    def update(self, channel):
-        if GPIO.input(self.gpio_number):
-            logging.info("motion detected")
-            self.ioloop.add_callback(self.update_bright_prop, True)
+    def __update(self, gpio_number):
+        if GPIO.input(gpio_number):
+            self.ioloop.add_callback(self.__update_bright_prop, False)
         else:
-            self.ioloop.add_callback(self.update_bright_prop, False)
+            self.ioloop.add_callback(self.__update_bright_prop, True)
 
-    def update_bright_prop(self, is_bright):
-        if is_bright:
-            self.bright.notify_of_external_update(True)
-        else:
-            self.bright.notify_of_external_update(False)
-
-    def read_gpio(self):
-        if GPIO.input(self.gpio_number):
-            logging.info("state updated: False")
-            return False
-        else:
-            logging.info("state updated: True")
-            return True
+    def __update_bright_prop(self, is_bright):
+        self.bright.notify_of_external_update(is_bright)
+        logging.info("is_bright: " + str(is_bright))
 
 
 def run_server(port, gpio_number, description):
